from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Resources.Core
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage
import win32more.Windows.Storage.Streams
import win32more.Windows.UI
import win32more.Windows.Win32.System.WinRT
class INamedResource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Core.INamedResource'
    _iid_ = Guid('{1c98c219-0b13-4240-89a5-d495dc189a00}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_Candidates(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate]: ...
    @winrt_commethod(8)
    def Resolve(self) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate: ...
    @winrt_commethod(9)
    def ResolveForContext(self, resourceContext: win32more.Windows.ApplicationModel.Resources.Core.ResourceContext) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate: ...
    @winrt_commethod(10)
    def ResolveAll(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate]: ...
    @winrt_commethod(11)
    def ResolveAllForContext(self, resourceContext: win32more.Windows.ApplicationModel.Resources.Core.ResourceContext) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate]: ...
    Candidates = property(get_Candidates, None)
    Uri = property(get_Uri, None)
class IResourceCandidate(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Core.IResourceCandidate'
    _iid_ = Guid('{af5207d9-c433-4764-b3fd-8fa6bfbcbadc}')
    @winrt_commethod(6)
    def get_Qualifiers(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier]: ...
    @winrt_commethod(7)
    def get_IsMatch(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_IsMatchAsDefault(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_IsDefault(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_ValueAsString(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def GetValueAsFileAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_commethod(12)
    def GetQualifierValue(self, qualifierName: WinRT_String) -> WinRT_String: ...
    IsDefault = property(get_IsDefault, None)
    IsMatch = property(get_IsMatch, None)
    IsMatchAsDefault = property(get_IsMatchAsDefault, None)
    Qualifiers = property(get_Qualifiers, None)
    ValueAsString = property(get_ValueAsString, None)
class IResourceCandidate2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Core.IResourceCandidate2'
    _iid_ = Guid('{69e5b468-f6fc-4013-aaa2-d53f1757d3b5}')
    @winrt_commethod(6)
    def GetValueAsStreamAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
class IResourceCandidate3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Core.IResourceCandidate3'
    _iid_ = Guid('{08ae97f8-517a-4674-958c-4a3c7cd2cc6b}')
    @winrt_commethod(6)
    def get_Kind(self) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidateKind: ...
    Kind = property(get_Kind, None)
class IResourceContext(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Core.IResourceContext'
    _iid_ = Guid('{2fa22f4b-707e-4b27-ad0d-d0d8cd468fd2}')
    @winrt_commethod(6)
    def get_QualifierValues(self) -> win32more.Windows.Foundation.Collections.IObservableMap[WinRT_String, WinRT_String]: ...
    @winrt_commethod(7)
    def Reset(self) -> Void: ...
    @winrt_commethod(8)
    def ResetQualifierValues(self, qualifierNames: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> Void: ...
    @winrt_commethod(9)
    def OverrideToMatch(self, result: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier]) -> Void: ...
    @winrt_commethod(10)
    def Clone(self) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceContext: ...
    @winrt_commethod(11)
    def get_Languages(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(12)
    def put_Languages(self, languages: win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]) -> Void: ...
    Languages = property(get_Languages, put_Languages)
    QualifierValues = property(get_QualifierValues, None)
class IResourceContextStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Core.IResourceContextStatics'
    _iid_ = Guid('{98be9d6c-6338-4b31-99df-b2b442f17149}')
    @winrt_commethod(6)
    def CreateMatchingContext(self, result: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier]) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceContext: ...
class IResourceContextStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Core.IResourceContextStatics2'
    _iid_ = Guid('{41f752ef-12af-41b9-ab36-b1eb4b512460}')
    @winrt_commethod(6)
    def GetForCurrentView(self) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceContext: ...
    @winrt_commethod(7)
    def SetGlobalQualifierValue(self, key: WinRT_String, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def ResetGlobalQualifierValues(self) -> Void: ...
    @winrt_commethod(9)
    def ResetGlobalQualifierValuesForSpecifiedQualifiers(self, qualifierNames: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> Void: ...
    @winrt_commethod(10)
    def GetForViewIndependentUse(self) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceContext: ...
class IResourceContextStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Core.IResourceContextStatics3'
    _iid_ = Guid('{20cf492c-af0f-450b-9da6-106dd0c29a39}')
    @winrt_commethod(6)
    def SetGlobalQualifierValueWithPersistence(self, key: WinRT_String, value: WinRT_String, persistence: win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifierPersistence) -> Void: ...
class IResourceContextStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Core.IResourceContextStatics4'
    _iid_ = Guid('{22eb9ccd-fb31-4bfa-b86b-df9d9d7bdc39}')
    @winrt_commethod(6)
    def GetForUIContext(self, context: win32more.Windows.UI.UIContext) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceContext: ...
class IResourceManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Core.IResourceManager'
    _iid_ = Guid('{f744d97b-9988-44fb-abd6-5378844cfa8b}')
    @winrt_commethod(6)
    def get_MainResourceMap(self) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceMap: ...
    @winrt_commethod(7)
    def get_AllResourceMaps(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]: ...
    @winrt_commethod(8)
    def get_DefaultContext(self) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceContext: ...
    @winrt_commethod(9)
    def LoadPriFiles(self, files: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Storage.IStorageFile]) -> Void: ...
    @winrt_commethod(10)
    def UnloadPriFiles(self, files: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Storage.IStorageFile]) -> Void: ...
    AllResourceMaps = property(get_AllResourceMaps, None)
    DefaultContext = property(get_DefaultContext, None)
    MainResourceMap = property(get_MainResourceMap, None)
class IResourceManager2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Core.IResourceManager2'
    _iid_ = Guid('{9d66fe6c-a4d7-4c23-9e85-675f304c252d}')
    @winrt_commethod(6)
    def GetAllNamedResourcesForPackage(self, packageName: WinRT_String, resourceLayoutInfo: win32more.Windows.ApplicationModel.Resources.Core.ResourceLayoutInfo) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.NamedResource]: ...
    @winrt_commethod(7)
    def GetAllSubtreesForPackage(self, packageName: WinRT_String, resourceLayoutInfo: win32more.Windows.ApplicationModel.Resources.Core.ResourceLayoutInfo) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]: ...
class IResourceManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Core.IResourceManagerStatics'
    _iid_ = Guid('{1cc0fdfc-69ee-4e43-9901-47f12687baf7}')
    @winrt_commethod(6)
    def get_Current(self) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceManager: ...
    @winrt_commethod(7)
    def IsResourceReference(self, resourceReference: WinRT_String) -> Boolean: ...
    Current = property(get_Current, None)
class IResourceMap(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[MappingProtocol[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource]]
    _classid_ = 'Windows.ApplicationModel.Resources.Core.IResourceMap'
    _iid_ = Guid('{72284824-db8c-42f8-b08c-53ff357dad82}')
    @winrt_commethod(6)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def GetValue(self, resource: WinRT_String) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate: ...
    @winrt_commethod(8)
    def GetValueForContext(self, resource: WinRT_String, context: win32more.Windows.ApplicationModel.Resources.Core.ResourceContext) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate: ...
    @winrt_commethod(9)
    def GetSubtree(self, reference: WinRT_String) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceMap: ...
    Uri = property(get_Uri, None)
class IResourceQualifier(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Core.IResourceQualifier'
    _iid_ = Guid('{785da5b2-4afd-4376-a888-c5f9a6b7a05c}')
    @winrt_commethod(6)
    def get_QualifierName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_QualifierValue(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_IsDefault(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_IsMatch(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_Score(self) -> Double: ...
    IsDefault = property(get_IsDefault, None)
    IsMatch = property(get_IsMatch, None)
    QualifierName = property(get_QualifierName, None)
    QualifierValue = property(get_QualifierValue, None)
    Score = property(get_Score, None)
class NamedResource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Resources.Core.INamedResource
    _classid_ = 'Windows.ApplicationModel.Resources.Core.NamedResource'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.ApplicationModel.Resources.Core.INamedResource) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_Candidates(self: win32more.Windows.ApplicationModel.Resources.Core.INamedResource) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate]: ...
    @winrt_mixinmethod
    def Resolve(self: win32more.Windows.ApplicationModel.Resources.Core.INamedResource) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate: ...
    @winrt_mixinmethod
    def ResolveForContext(self: win32more.Windows.ApplicationModel.Resources.Core.INamedResource, resourceContext: win32more.Windows.ApplicationModel.Resources.Core.ResourceContext) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate: ...
    @winrt_mixinmethod
    def ResolveAll(self: win32more.Windows.ApplicationModel.Resources.Core.INamedResource) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate]: ...
    @winrt_mixinmethod
    def ResolveAllForContext(self: win32more.Windows.ApplicationModel.Resources.Core.INamedResource, resourceContext: win32more.Windows.ApplicationModel.Resources.Core.ResourceContext) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate]: ...
    Candidates = property(get_Candidates, None)
    Uri = property(get_Uri, None)
class ResourceCandidate(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Resources.Core.IResourceCandidate
    _classid_ = 'Windows.ApplicationModel.Resources.Core.ResourceCandidate'
    @winrt_mixinmethod
    def get_Qualifiers(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceCandidate) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier]: ...
    @winrt_mixinmethod
    def get_IsMatch(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceCandidate) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsMatchAsDefault(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceCandidate) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsDefault(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceCandidate) -> Boolean: ...
    @winrt_mixinmethod
    def get_ValueAsString(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceCandidate) -> WinRT_String: ...
    @winrt_mixinmethod
    def GetValueAsFileAsync(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceCandidate) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def GetQualifierValue(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceCandidate, qualifierName: WinRT_String) -> WinRT_String: ...
    @winrt_mixinmethod
    def GetValueAsStreamAsync(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceCandidate2) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_mixinmethod
    def get_Kind(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceCandidate3) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidateKind: ...
    IsDefault = property(get_IsDefault, None)
    IsMatch = property(get_IsMatch, None)
    IsMatchAsDefault = property(get_IsMatchAsDefault, None)
    Kind = property(get_Kind, None)
    Qualifiers = property(get_Qualifiers, None)
    ValueAsString = property(get_ValueAsString, None)
class ResourceCandidateKind(Enum, Int32):
    String = 0
    File = 1
    EmbeddedData = 2
class ResourceCandidateVectorView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate]]
    default_interface: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate]
    _classid_ = 'Windows.ApplicationModel.Resources.Core.ResourceCandidateVectorView'
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate], index: UInt32) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate]) -> UInt32: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate], value: win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate], startIndex: UInt32, items: FillArray[win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate]) -> UInt32: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate]: ...
    Size = property(get_Size, None)
class ResourceContext(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Resources.Core.IResourceContext
    _classid_ = 'Windows.ApplicationModel.Resources.Core.ResourceContext'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.Resources.Core.ResourceContext.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceContext: ...
    @winrt_mixinmethod
    def get_QualifierValues(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceContext) -> win32more.Windows.Foundation.Collections.IObservableMap[WinRT_String, WinRT_String]: ...
    @winrt_mixinmethod
    def Reset(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceContext) -> Void: ...
    @winrt_mixinmethod
    def ResetQualifierValues(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceContext, qualifierNames: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> Void: ...
    @winrt_mixinmethod
    def OverrideToMatch(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceContext, result: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier]) -> Void: ...
    @winrt_mixinmethod
    def Clone(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceContext) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceContext: ...
    @winrt_mixinmethod
    def get_Languages(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceContext) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def put_Languages(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceContext, languages: win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]) -> Void: ...
    @winrt_classmethod
    def GetForUIContext(cls: win32more.Windows.ApplicationModel.Resources.Core.IResourceContextStatics4, context: win32more.Windows.UI.UIContext) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceContext: ...
    @winrt_classmethod
    def SetGlobalQualifierValueWithPersistence(cls: win32more.Windows.ApplicationModel.Resources.Core.IResourceContextStatics3, key: WinRT_String, value: WinRT_String, persistence: win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifierPersistence) -> Void: ...
    @winrt_classmethod
    def GetForCurrentView(cls: win32more.Windows.ApplicationModel.Resources.Core.IResourceContextStatics2) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceContext: ...
    @winrt_classmethod
    def SetGlobalQualifierValue(cls: win32more.Windows.ApplicationModel.Resources.Core.IResourceContextStatics2, key: WinRT_String, value: WinRT_String) -> Void: ...
    @winrt_classmethod
    def ResetGlobalQualifierValues(cls: win32more.Windows.ApplicationModel.Resources.Core.IResourceContextStatics2) -> Void: ...
    @winrt_classmethod
    def ResetGlobalQualifierValuesForSpecifiedQualifiers(cls: win32more.Windows.ApplicationModel.Resources.Core.IResourceContextStatics2, qualifierNames: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> Void: ...
    @winrt_classmethod
    def GetForViewIndependentUse(cls: win32more.Windows.ApplicationModel.Resources.Core.IResourceContextStatics2) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceContext: ...
    @winrt_classmethod
    def CreateMatchingContext(cls: win32more.Windows.ApplicationModel.Resources.Core.IResourceContextStatics, result: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier]) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceContext: ...
    Languages = property(get_Languages, put_Languages)
    QualifierValues = property(get_QualifierValues, None)
class ResourceContextLanguagesVectorView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[WinRT_String]]
    default_interface: win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]
    _classid_ = 'Windows.ApplicationModel.Resources.Core.ResourceContextLanguagesVectorView'
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVectorView[WinRT_String], index: UInt32) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]) -> UInt32: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVectorView[WinRT_String], value: WinRT_String, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVectorView[WinRT_String], startIndex: UInt32, items: FillArray[WinRT_String]) -> UInt32: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.Collections.IIterator[WinRT_String]: ...
    Size = property(get_Size, None)
class ResourceLayoutInfo(Structure):
    MajorVersion: UInt32
    MinorVersion: UInt32
    ResourceSubtreeCount: UInt32
    NamedResourceCount: UInt32
    Checksum: Int32
class _ResourceManager_Meta_(ComPtr.__class__):
    pass
class ResourceManager(ComPtr, metaclass=_ResourceManager_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Resources.Core.IResourceManager
    _classid_ = 'Windows.ApplicationModel.Resources.Core.ResourceManager'
    @winrt_mixinmethod
    def get_MainResourceMap(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceManager) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceMap: ...
    @winrt_mixinmethod
    def get_AllResourceMaps(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceManager) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]: ...
    @winrt_mixinmethod
    def get_DefaultContext(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceManager) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceContext: ...
    @winrt_mixinmethod
    def LoadPriFiles(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceManager, files: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Storage.IStorageFile]) -> Void: ...
    @winrt_mixinmethod
    def UnloadPriFiles(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceManager, files: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Storage.IStorageFile]) -> Void: ...
    @winrt_mixinmethod
    def GetAllNamedResourcesForPackage(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceManager2, packageName: WinRT_String, resourceLayoutInfo: win32more.Windows.ApplicationModel.Resources.Core.ResourceLayoutInfo) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.NamedResource]: ...
    @winrt_mixinmethod
    def GetAllSubtreesForPackage(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceManager2, packageName: WinRT_String, resourceLayoutInfo: win32more.Windows.ApplicationModel.Resources.Core.ResourceLayoutInfo) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]: ...
    @winrt_classmethod
    def get_Current(cls: win32more.Windows.ApplicationModel.Resources.Core.IResourceManagerStatics) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceManager: ...
    @winrt_classmethod
    def IsResourceReference(cls: win32more.Windows.ApplicationModel.Resources.Core.IResourceManagerStatics, resourceReference: WinRT_String) -> Boolean: ...
    AllResourceMaps = property(get_AllResourceMaps, None)
    DefaultContext = property(get_DefaultContext, None)
    MainResourceMap = property(get_MainResourceMap, None)
    _ResourceManager_Meta_.Current = property(get_Current, None)
class ResourceMap(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[MappingProtocol[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource]]
    default_interface: win32more.Windows.ApplicationModel.Resources.Core.IResourceMap
    _classid_ = 'Windows.ApplicationModel.Resources.Core.ResourceMap'
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceMap) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def GetValue(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceMap, resource: WinRT_String) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate: ...
    @winrt_mixinmethod
    def GetValueForContext(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceMap, resource: WinRT_String, context: win32more.Windows.ApplicationModel.Resources.Core.ResourceContext) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceCandidate: ...
    @winrt_mixinmethod
    def GetSubtree(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceMap, reference: WinRT_String) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceMap: ...
    @winrt_mixinmethod
    def Lookup(self: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource], key: WinRT_String) -> win32more.Windows.ApplicationModel.Resources.Core.NamedResource: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource]) -> UInt32: ...
    @winrt_mixinmethod
    def HasKey(self: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource], key: WinRT_String) -> Boolean: ...
    @winrt_mixinmethod
    def Split(self: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource], first: POINTER(win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource]), second: POINTER(win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource])) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource]]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource]]: ...
    Size = property(get_Size, None)
    Uri = property(get_Uri, None)
class ResourceMapIterator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource]]
    _classid_ = 'Windows.ApplicationModel.Resources.Core.ResourceMapIterator'
    @winrt_mixinmethod
    def get_Current(self: win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource]]) -> win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource]: ...
    @winrt_mixinmethod
    def get_HasCurrent(self: win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource]]) -> Boolean: ...
    @winrt_mixinmethod
    def MoveNext(self: win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource]]) -> Boolean: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource]], items: FillArray[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.NamedResource]]) -> UInt32: ...
    Current = property(get_Current, None)
    HasCurrent = property(get_HasCurrent, None)
class ResourceMapMapView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[MappingProtocol[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]]
    default_interface: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]
    _classid_ = 'Windows.ApplicationModel.Resources.Core.ResourceMapMapView'
    @winrt_mixinmethod
    def Lookup(self: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap], key: WinRT_String) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceMap: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]) -> UInt32: ...
    @winrt_mixinmethod
    def HasKey(self: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap], key: WinRT_String) -> Boolean: ...
    @winrt_mixinmethod
    def Split(self: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap], first: POINTER(win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]), second: POINTER(win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap])) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]]: ...
    Size = property(get_Size, None)
class ResourceMapMapViewIterator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]]
    _classid_ = 'Windows.ApplicationModel.Resources.Core.ResourceMapMapViewIterator'
    @winrt_mixinmethod
    def get_Current(self: win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]]) -> win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]: ...
    @winrt_mixinmethod
    def get_HasCurrent(self: win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]]) -> Boolean: ...
    @winrt_mixinmethod
    def MoveNext(self: win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]]) -> Boolean: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]], items: FillArray[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.ApplicationModel.Resources.Core.ResourceMap]]) -> UInt32: ...
    Current = property(get_Current, None)
    HasCurrent = property(get_HasCurrent, None)
class ResourceQualifier(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Resources.Core.IResourceQualifier
    _classid_ = 'Windows.ApplicationModel.Resources.Core.ResourceQualifier'
    @winrt_mixinmethod
    def get_QualifierName(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceQualifier) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_QualifierValue(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceQualifier) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_IsDefault(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceQualifier) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsMatch(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceQualifier) -> Boolean: ...
    @winrt_mixinmethod
    def get_Score(self: win32more.Windows.ApplicationModel.Resources.Core.IResourceQualifier) -> Double: ...
    IsDefault = property(get_IsDefault, None)
    IsMatch = property(get_IsMatch, None)
    QualifierName = property(get_QualifierName, None)
    QualifierValue = property(get_QualifierValue, None)
    Score = property(get_Score, None)
class ResourceQualifierMapView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[MappingProtocol[WinRT_String, WinRT_String]]
    default_interface: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]
    _classid_ = 'Windows.ApplicationModel.Resources.Core.ResourceQualifierMapView'
    @winrt_mixinmethod
    def Lookup(self: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String], key: WinRT_String) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]) -> UInt32: ...
    @winrt_mixinmethod
    def HasKey(self: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String], key: WinRT_String) -> Boolean: ...
    @winrt_mixinmethod
    def Split(self: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String], first: POINTER(win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]), second: POINTER(win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String])) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, WinRT_String]]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, WinRT_String]]: ...
    Size = property(get_Size, None)
class ResourceQualifierObservableMap(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[MappingProtocol[WinRT_String, WinRT_String]]
    default_interface: win32more.Windows.Foundation.Collections.IObservableMap[WinRT_String, WinRT_String]
    _classid_ = 'Windows.ApplicationModel.Resources.Core.ResourceQualifierObservableMap'
    @winrt_mixinmethod
    def add_MapChanged(self: win32more.Windows.Foundation.Collections.IObservableMap[WinRT_String, WinRT_String], vhnd: win32more.Windows.Foundation.Collections.MapChangedEventHandler[WinRT_String, WinRT_String]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_MapChanged(self: win32more.Windows.Foundation.Collections.IObservableMap[WinRT_String, WinRT_String], token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Lookup(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String], key: WinRT_String) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]) -> UInt32: ...
    @winrt_mixinmethod
    def HasKey(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String], key: WinRT_String) -> Boolean: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]: ...
    @winrt_mixinmethod
    def Insert(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String], key: WinRT_String, value: WinRT_String) -> Boolean: ...
    @winrt_mixinmethod
    def Remove(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String], key: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, WinRT_String]]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, WinRT_String]]: ...
    Size = property(get_Size, None)
    MapChanged = event()
class ResourceQualifierPersistence(Enum, Int32):
    None_ = 0
    LocalMachine = 1
class ResourceQualifierVectorView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier]]
    default_interface: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier]
    _classid_ = 'Windows.ApplicationModel.Resources.Core.ResourceQualifierVectorView'
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier], index: UInt32) -> win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier]) -> UInt32: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier], value: win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier], startIndex: UInt32, items: FillArray[win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier]) -> UInt32: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.ApplicationModel.Resources.Core.ResourceQualifier]: ...
    Size = property(get_Size, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Data.Text
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.UI.Text.Core
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
class AlternateNormalizationFormat(Enum, Int32):
    NotNormalized = 0
    Number = 1
    Currency = 3
    Date = 4
    Time = 5
class AlternateWordForm(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Text.IAlternateWordForm
    _classid_ = 'Windows.Data.Text.AlternateWordForm'
    @winrt_mixinmethod
    def get_SourceTextSegment(self: win32more.Windows.Data.Text.IAlternateWordForm) -> win32more.Windows.Data.Text.TextSegment: ...
    @winrt_mixinmethod
    def get_AlternateText(self: win32more.Windows.Data.Text.IAlternateWordForm) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_NormalizationFormat(self: win32more.Windows.Data.Text.IAlternateWordForm) -> win32more.Windows.Data.Text.AlternateNormalizationFormat: ...
    AlternateText = property(get_AlternateText, None)
    NormalizationFormat = property(get_NormalizationFormat, None)
    SourceTextSegment = property(get_SourceTextSegment, None)
class IAlternateWordForm(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.IAlternateWordForm'
    _iid_ = Guid('{47396c1e-51b9-4207-9146-248e636a1d1d}')
    @winrt_commethod(6)
    def get_SourceTextSegment(self) -> win32more.Windows.Data.Text.TextSegment: ...
    @winrt_commethod(7)
    def get_AlternateText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_NormalizationFormat(self) -> win32more.Windows.Data.Text.AlternateNormalizationFormat: ...
    AlternateText = property(get_AlternateText, None)
    NormalizationFormat = property(get_NormalizationFormat, None)
    SourceTextSegment = property(get_SourceTextSegment, None)
class ISelectableWordSegment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.ISelectableWordSegment'
    _iid_ = Guid('{916a4cb7-8aa7-4c78-b374-5dedb752e60b}')
    @winrt_commethod(6)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_SourceTextSegment(self) -> win32more.Windows.Data.Text.TextSegment: ...
    SourceTextSegment = property(get_SourceTextSegment, None)
    Text = property(get_Text, None)
class ISelectableWordsSegmenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.ISelectableWordsSegmenter'
    _iid_ = Guid('{f6dc31e7-4b13-45c5-8897-7d71269e085d}')
    @winrt_commethod(6)
    def get_ResolvedLanguage(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def GetTokenAt(self, text: WinRT_String, startIndex: UInt32) -> win32more.Windows.Data.Text.SelectableWordSegment: ...
    @winrt_commethod(8)
    def GetTokens(self, text: WinRT_String) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Text.SelectableWordSegment]: ...
    @winrt_commethod(9)
    def Tokenize(self, text: WinRT_String, startIndex: UInt32, handler: win32more.Windows.Data.Text.SelectableWordSegmentsTokenizingHandler) -> Void: ...
    ResolvedLanguage = property(get_ResolvedLanguage, None)
class ISelectableWordsSegmenterFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.ISelectableWordsSegmenterFactory'
    _iid_ = Guid('{8c7a7648-6057-4339-bc70-f210010a4150}')
    @winrt_commethod(6)
    def CreateWithLanguage(self, language: WinRT_String) -> win32more.Windows.Data.Text.SelectableWordsSegmenter: ...
class ISemanticTextQuery(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.ISemanticTextQuery'
    _iid_ = Guid('{6a1cab51-1fb2-4909-80b8-35731a2b3e7f}')
    @winrt_commethod(6)
    def Find(self, content: WinRT_String) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Text.TextSegment]: ...
    @winrt_commethod(7)
    def FindInProperty(self, propertyContent: WinRT_String, propertyName: WinRT_String) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Text.TextSegment]: ...
class ISemanticTextQueryFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.ISemanticTextQueryFactory'
    _iid_ = Guid('{238c0503-f995-4587-8777-a2b7d80acfef}')
    @winrt_commethod(6)
    def Create(self, aqsFilter: WinRT_String) -> win32more.Windows.Data.Text.SemanticTextQuery: ...
    @winrt_commethod(7)
    def CreateWithLanguage(self, aqsFilter: WinRT_String, filterLanguage: WinRT_String) -> win32more.Windows.Data.Text.SemanticTextQuery: ...
class ITextConversionGenerator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.ITextConversionGenerator'
    _iid_ = Guid('{03606a5e-2aa9-4ab6-af8b-a562b63a8992}')
    @winrt_commethod(6)
    def get_ResolvedLanguage(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_LanguageAvailableButNotInstalled(self) -> Boolean: ...
    @winrt_commethod(8)
    def GetCandidatesAsync(self, input: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    @winrt_commethod(9)
    def GetCandidatesWithMaxCountAsync(self, input: WinRT_String, maxCandidates: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    LanguageAvailableButNotInstalled = property(get_LanguageAvailableButNotInstalled, None)
    ResolvedLanguage = property(get_ResolvedLanguage, None)
class ITextConversionGeneratorFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.ITextConversionGeneratorFactory'
    _iid_ = Guid('{fcaa3781-3083-49ab-be15-56dfbbb74d6f}')
    @winrt_commethod(6)
    def Create(self, languageTag: WinRT_String) -> win32more.Windows.Data.Text.TextConversionGenerator: ...
class ITextPhoneme(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.ITextPhoneme'
    _iid_ = Guid('{9362a40a-9b7a-4569-94cf-d84f2f38cf9b}')
    @winrt_commethod(6)
    def get_DisplayText(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_ReadingText(self) -> WinRT_String: ...
    DisplayText = property(get_DisplayText, None)
    ReadingText = property(get_ReadingText, None)
class ITextPredictionGenerator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.ITextPredictionGenerator'
    _iid_ = Guid('{5eacab07-abf1-4cb6-9d9e-326f2b468756}')
    @winrt_commethod(6)
    def get_ResolvedLanguage(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_LanguageAvailableButNotInstalled(self) -> Boolean: ...
    @winrt_commethod(8)
    def GetCandidatesAsync(self, input: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    @winrt_commethod(9)
    def GetCandidatesWithMaxCountAsync(self, input: WinRT_String, maxCandidates: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    LanguageAvailableButNotInstalled = property(get_LanguageAvailableButNotInstalled, None)
    ResolvedLanguage = property(get_ResolvedLanguage, None)
class ITextPredictionGenerator2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.ITextPredictionGenerator2'
    _iid_ = Guid('{b84723b8-2c77-486a-900a-a3453eedc15d}')
    @winrt_commethod(6)
    def GetCandidatesWithParametersAsync(self, input: WinRT_String, maxCandidates: UInt32, predictionOptions: win32more.Windows.Data.Text.TextPredictionOptions, previousStrings: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    @winrt_commethod(7)
    def GetNextWordCandidatesAsync(self, maxCandidates: UInt32, previousStrings: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    @winrt_commethod(8)
    def get_InputScope(self) -> win32more.Windows.UI.Text.Core.CoreTextInputScope: ...
    @winrt_commethod(9)
    def put_InputScope(self, value: win32more.Windows.UI.Text.Core.CoreTextInputScope) -> Void: ...
    InputScope = property(get_InputScope, put_InputScope)
class ITextPredictionGeneratorFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.ITextPredictionGeneratorFactory'
    _iid_ = Guid('{7257b416-8ba2-4751-9d30-9d85435653a2}')
    @winrt_commethod(6)
    def Create(self, languageTag: WinRT_String) -> win32more.Windows.Data.Text.TextPredictionGenerator: ...
class ITextReverseConversionGenerator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.ITextReverseConversionGenerator'
    _iid_ = Guid('{51e7f514-9c51-4d86-ae1b-b498fbad8313}')
    @winrt_commethod(6)
    def get_ResolvedLanguage(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_LanguageAvailableButNotInstalled(self) -> Boolean: ...
    @winrt_commethod(8)
    def ConvertBackAsync(self, input: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[WinRT_String]: ...
    LanguageAvailableButNotInstalled = property(get_LanguageAvailableButNotInstalled, None)
    ResolvedLanguage = property(get_ResolvedLanguage, None)
class ITextReverseConversionGenerator2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.ITextReverseConversionGenerator2'
    _iid_ = Guid('{1aafd2ec-85d6-46fd-828a-3a4830fa6e18}')
    @winrt_commethod(6)
    def GetPhonemesAsync(self, input: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Text.TextPhoneme]]: ...
class ITextReverseConversionGeneratorFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.ITextReverseConversionGeneratorFactory'
    _iid_ = Guid('{63bed326-1fda-41f6-89d5-23ddea3c729a}')
    @winrt_commethod(6)
    def Create(self, languageTag: WinRT_String) -> win32more.Windows.Data.Text.TextReverseConversionGenerator: ...
class IUnicodeCharactersStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.IUnicodeCharactersStatics'
    _iid_ = Guid('{97909e87-9291-4f91-b6c8-b6e359d7a7fb}')
    @winrt_commethod(6)
    def GetCodepointFromSurrogatePair(self, highSurrogate: UInt32, lowSurrogate: UInt32) -> UInt32: ...
    @winrt_commethod(7)
    def GetSurrogatePairFromCodepoint(self, codepoint: UInt32, highSurrogate: POINTER(Char), lowSurrogate: POINTER(Char)) -> Void: ...
    @winrt_commethod(8)
    def IsHighSurrogate(self, codepoint: UInt32) -> Boolean: ...
    @winrt_commethod(9)
    def IsLowSurrogate(self, codepoint: UInt32) -> Boolean: ...
    @winrt_commethod(10)
    def IsSupplementary(self, codepoint: UInt32) -> Boolean: ...
    @winrt_commethod(11)
    def IsNoncharacter(self, codepoint: UInt32) -> Boolean: ...
    @winrt_commethod(12)
    def IsWhitespace(self, codepoint: UInt32) -> Boolean: ...
    @winrt_commethod(13)
    def IsAlphabetic(self, codepoint: UInt32) -> Boolean: ...
    @winrt_commethod(14)
    def IsCased(self, codepoint: UInt32) -> Boolean: ...
    @winrt_commethod(15)
    def IsUppercase(self, codepoint: UInt32) -> Boolean: ...
    @winrt_commethod(16)
    def IsLowercase(self, codepoint: UInt32) -> Boolean: ...
    @winrt_commethod(17)
    def IsIdStart(self, codepoint: UInt32) -> Boolean: ...
    @winrt_commethod(18)
    def IsIdContinue(self, codepoint: UInt32) -> Boolean: ...
    @winrt_commethod(19)
    def IsGraphemeBase(self, codepoint: UInt32) -> Boolean: ...
    @winrt_commethod(20)
    def IsGraphemeExtend(self, codepoint: UInt32) -> Boolean: ...
    @winrt_commethod(21)
    def GetNumericType(self, codepoint: UInt32) -> win32more.Windows.Data.Text.UnicodeNumericType: ...
    @winrt_commethod(22)
    def GetGeneralCategory(self, codepoint: UInt32) -> win32more.Windows.Data.Text.UnicodeGeneralCategory: ...
class IWordSegment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.IWordSegment'
    _iid_ = Guid('{d2d4ba6d-987c-4cc0-b6bd-d49a11b38f9a}')
    @winrt_commethod(6)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_SourceTextSegment(self) -> win32more.Windows.Data.Text.TextSegment: ...
    @winrt_commethod(8)
    def get_AlternateForms(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Text.AlternateWordForm]: ...
    AlternateForms = property(get_AlternateForms, None)
    SourceTextSegment = property(get_SourceTextSegment, None)
    Text = property(get_Text, None)
class IWordsSegmenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.IWordsSegmenter'
    _iid_ = Guid('{86b4d4d1-b2fe-4e34-a81d-66640300454f}')
    @winrt_commethod(6)
    def get_ResolvedLanguage(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def GetTokenAt(self, text: WinRT_String, startIndex: UInt32) -> win32more.Windows.Data.Text.WordSegment: ...
    @winrt_commethod(8)
    def GetTokens(self, text: WinRT_String) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Text.WordSegment]: ...
    @winrt_commethod(9)
    def Tokenize(self, text: WinRT_String, startIndex: UInt32, handler: win32more.Windows.Data.Text.WordSegmentsTokenizingHandler) -> Void: ...
    ResolvedLanguage = property(get_ResolvedLanguage, None)
class IWordsSegmenterFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.IWordsSegmenterFactory'
    _iid_ = Guid('{e6977274-fc35-455c-8bfb-6d7f4653ca97}')
    @winrt_commethod(6)
    def CreateWithLanguage(self, language: WinRT_String) -> win32more.Windows.Data.Text.WordsSegmenter: ...
class SelectableWordSegment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Text.ISelectableWordSegment
    _classid_ = 'Windows.Data.Text.SelectableWordSegment'
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.Data.Text.ISelectableWordSegment) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SourceTextSegment(self: win32more.Windows.Data.Text.ISelectableWordSegment) -> win32more.Windows.Data.Text.TextSegment: ...
    SourceTextSegment = property(get_SourceTextSegment, None)
    Text = property(get_Text, None)
class SelectableWordSegmentsTokenizingHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3a3dfc9c-aede-4dc7-9e6c-41c044bd3592}')
    @winrt_commethod(3)
    def Invoke(self, precedingWords: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Data.Text.SelectableWordSegment], words: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Data.Text.SelectableWordSegment]) -> Void: ...
class SelectableWordsSegmenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Text.ISelectableWordsSegmenter
    _classid_ = 'Windows.Data.Text.SelectableWordsSegmenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Data.Text.SelectableWordsSegmenter.CreateWithLanguage(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateWithLanguage(cls: win32more.Windows.Data.Text.ISelectableWordsSegmenterFactory, language: WinRT_String) -> win32more.Windows.Data.Text.SelectableWordsSegmenter: ...
    @winrt_mixinmethod
    def get_ResolvedLanguage(self: win32more.Windows.Data.Text.ISelectableWordsSegmenter) -> WinRT_String: ...
    @winrt_mixinmethod
    def GetTokenAt(self: win32more.Windows.Data.Text.ISelectableWordsSegmenter, text: WinRT_String, startIndex: UInt32) -> win32more.Windows.Data.Text.SelectableWordSegment: ...
    @winrt_mixinmethod
    def GetTokens(self: win32more.Windows.Data.Text.ISelectableWordsSegmenter, text: WinRT_String) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Text.SelectableWordSegment]: ...
    @winrt_mixinmethod
    def Tokenize(self: win32more.Windows.Data.Text.ISelectableWordsSegmenter, text: WinRT_String, startIndex: UInt32, handler: win32more.Windows.Data.Text.SelectableWordSegmentsTokenizingHandler) -> Void: ...
    ResolvedLanguage = property(get_ResolvedLanguage, None)
class SemanticTextQuery(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Text.ISemanticTextQuery
    _classid_ = 'Windows.Data.Text.SemanticTextQuery'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Data.Text.SemanticTextQuery.Create(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Data.Text.SemanticTextQuery.CreateWithLanguage(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Data.Text.ISemanticTextQueryFactory, aqsFilter: WinRT_String) -> win32more.Windows.Data.Text.SemanticTextQuery: ...
    @winrt_factorymethod
    def CreateWithLanguage(cls: win32more.Windows.Data.Text.ISemanticTextQueryFactory, aqsFilter: WinRT_String, filterLanguage: WinRT_String) -> win32more.Windows.Data.Text.SemanticTextQuery: ...
    @winrt_mixinmethod
    def Find(self: win32more.Windows.Data.Text.ISemanticTextQuery, content: WinRT_String) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Text.TextSegment]: ...
    @winrt_mixinmethod
    def FindInProperty(self: win32more.Windows.Data.Text.ISemanticTextQuery, propertyContent: WinRT_String, propertyName: WinRT_String) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Text.TextSegment]: ...
class TextConversionGenerator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Text.ITextConversionGenerator
    _classid_ = 'Windows.Data.Text.TextConversionGenerator'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Data.Text.TextConversionGenerator.Create(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Data.Text.ITextConversionGeneratorFactory, languageTag: WinRT_String) -> win32more.Windows.Data.Text.TextConversionGenerator: ...
    @winrt_mixinmethod
    def get_ResolvedLanguage(self: win32more.Windows.Data.Text.ITextConversionGenerator) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_LanguageAvailableButNotInstalled(self: win32more.Windows.Data.Text.ITextConversionGenerator) -> Boolean: ...
    @winrt_mixinmethod
    def GetCandidatesAsync(self: win32more.Windows.Data.Text.ITextConversionGenerator, input: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    @winrt_mixinmethod
    def GetCandidatesWithMaxCountAsync(self: win32more.Windows.Data.Text.ITextConversionGenerator, input: WinRT_String, maxCandidates: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    LanguageAvailableButNotInstalled = property(get_LanguageAvailableButNotInstalled, None)
    ResolvedLanguage = property(get_ResolvedLanguage, None)
class TextPhoneme(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Text.ITextPhoneme
    _classid_ = 'Windows.Data.Text.TextPhoneme'
    @winrt_mixinmethod
    def get_DisplayText(self: win32more.Windows.Data.Text.ITextPhoneme) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ReadingText(self: win32more.Windows.Data.Text.ITextPhoneme) -> WinRT_String: ...
    DisplayText = property(get_DisplayText, None)
    ReadingText = property(get_ReadingText, None)
class TextPredictionGenerator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Text.ITextPredictionGenerator
    _classid_ = 'Windows.Data.Text.TextPredictionGenerator'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Data.Text.TextPredictionGenerator.Create(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Data.Text.ITextPredictionGeneratorFactory, languageTag: WinRT_String) -> win32more.Windows.Data.Text.TextPredictionGenerator: ...
    @winrt_mixinmethod
    def get_ResolvedLanguage(self: win32more.Windows.Data.Text.ITextPredictionGenerator) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_LanguageAvailableButNotInstalled(self: win32more.Windows.Data.Text.ITextPredictionGenerator) -> Boolean: ...
    @winrt_mixinmethod
    def GetCandidatesAsync(self: win32more.Windows.Data.Text.ITextPredictionGenerator, input: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    @winrt_mixinmethod
    def GetCandidatesWithMaxCountAsync(self: win32more.Windows.Data.Text.ITextPredictionGenerator, input: WinRT_String, maxCandidates: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    @winrt_mixinmethod
    def GetCandidatesWithParametersAsync(self: win32more.Windows.Data.Text.ITextPredictionGenerator2, input: WinRT_String, maxCandidates: UInt32, predictionOptions: win32more.Windows.Data.Text.TextPredictionOptions, previousStrings: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    @winrt_mixinmethod
    def GetNextWordCandidatesAsync(self: win32more.Windows.Data.Text.ITextPredictionGenerator2, maxCandidates: UInt32, previousStrings: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    @winrt_mixinmethod
    def get_InputScope(self: win32more.Windows.Data.Text.ITextPredictionGenerator2) -> win32more.Windows.UI.Text.Core.CoreTextInputScope: ...
    @winrt_mixinmethod
    def put_InputScope(self: win32more.Windows.Data.Text.ITextPredictionGenerator2, value: win32more.Windows.UI.Text.Core.CoreTextInputScope) -> Void: ...
    InputScope = property(get_InputScope, put_InputScope)
    LanguageAvailableButNotInstalled = property(get_LanguageAvailableButNotInstalled, None)
    ResolvedLanguage = property(get_ResolvedLanguage, None)
class TextPredictionOptions(Enum, UInt32):
    None_ = 0
    Predictions = 1
    Corrections = 2
class TextReverseConversionGenerator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Text.ITextReverseConversionGenerator
    _classid_ = 'Windows.Data.Text.TextReverseConversionGenerator'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Data.Text.TextReverseConversionGenerator.Create(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Data.Text.ITextReverseConversionGeneratorFactory, languageTag: WinRT_String) -> win32more.Windows.Data.Text.TextReverseConversionGenerator: ...
    @winrt_mixinmethod
    def get_ResolvedLanguage(self: win32more.Windows.Data.Text.ITextReverseConversionGenerator) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_LanguageAvailableButNotInstalled(self: win32more.Windows.Data.Text.ITextReverseConversionGenerator) -> Boolean: ...
    @winrt_mixinmethod
    def ConvertBackAsync(self: win32more.Windows.Data.Text.ITextReverseConversionGenerator, input: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[WinRT_String]: ...
    @winrt_mixinmethod
    def GetPhonemesAsync(self: win32more.Windows.Data.Text.ITextReverseConversionGenerator2, input: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Text.TextPhoneme]]: ...
    LanguageAvailableButNotInstalled = property(get_LanguageAvailableButNotInstalled, None)
    ResolvedLanguage = property(get_ResolvedLanguage, None)
class TextSegment(Structure):
    StartPosition: UInt32
    Length: UInt32
class UnicodeCharacters(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Text.UnicodeCharacters'
    @winrt_classmethod
    def GetCodepointFromSurrogatePair(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, highSurrogate: UInt32, lowSurrogate: UInt32) -> UInt32: ...
    @winrt_classmethod
    def GetSurrogatePairFromCodepoint(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32, highSurrogate: POINTER(Char), lowSurrogate: POINTER(Char)) -> Void: ...
    @winrt_classmethod
    def IsHighSurrogate(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32) -> Boolean: ...
    @winrt_classmethod
    def IsLowSurrogate(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32) -> Boolean: ...
    @winrt_classmethod
    def IsSupplementary(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32) -> Boolean: ...
    @winrt_classmethod
    def IsNoncharacter(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32) -> Boolean: ...
    @winrt_classmethod
    def IsWhitespace(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32) -> Boolean: ...
    @winrt_classmethod
    def IsAlphabetic(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32) -> Boolean: ...
    @winrt_classmethod
    def IsCased(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32) -> Boolean: ...
    @winrt_classmethod
    def IsUppercase(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32) -> Boolean: ...
    @winrt_classmethod
    def IsLowercase(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32) -> Boolean: ...
    @winrt_classmethod
    def IsIdStart(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32) -> Boolean: ...
    @winrt_classmethod
    def IsIdContinue(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32) -> Boolean: ...
    @winrt_classmethod
    def IsGraphemeBase(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32) -> Boolean: ...
    @winrt_classmethod
    def IsGraphemeExtend(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32) -> Boolean: ...
    @winrt_classmethod
    def GetNumericType(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32) -> win32more.Windows.Data.Text.UnicodeNumericType: ...
    @winrt_classmethod
    def GetGeneralCategory(cls: win32more.Windows.Data.Text.IUnicodeCharactersStatics, codepoint: UInt32) -> win32more.Windows.Data.Text.UnicodeGeneralCategory: ...
class UnicodeGeneralCategory(Enum, Int32):
    UppercaseLetter = 0
    LowercaseLetter = 1
    TitlecaseLetter = 2
    ModifierLetter = 3
    OtherLetter = 4
    NonspacingMark = 5
    SpacingCombiningMark = 6
    EnclosingMark = 7
    DecimalDigitNumber = 8
    LetterNumber = 9
    OtherNumber = 10
    SpaceSeparator = 11
    LineSeparator = 12
    ParagraphSeparator = 13
    Control = 14
    Format = 15
    Surrogate = 16
    PrivateUse = 17
    ConnectorPunctuation = 18
    DashPunctuation = 19
    OpenPunctuation = 20
    ClosePunctuation = 21
    InitialQuotePunctuation = 22
    FinalQuotePunctuation = 23
    OtherPunctuation = 24
    MathSymbol = 25
    CurrencySymbol = 26
    ModifierSymbol = 27
    OtherSymbol = 28
    NotAssigned = 29
class UnicodeNumericType(Enum, Int32):
    None_ = 0
    Decimal = 1
    Digit = 2
    Numeric = 3
class WordSegment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Text.IWordSegment
    _classid_ = 'Windows.Data.Text.WordSegment'
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.Data.Text.IWordSegment) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SourceTextSegment(self: win32more.Windows.Data.Text.IWordSegment) -> win32more.Windows.Data.Text.TextSegment: ...
    @winrt_mixinmethod
    def get_AlternateForms(self: win32more.Windows.Data.Text.IWordSegment) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Text.AlternateWordForm]: ...
    AlternateForms = property(get_AlternateForms, None)
    SourceTextSegment = property(get_SourceTextSegment, None)
    Text = property(get_Text, None)
class WordSegmentsTokenizingHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a5dd6357-bf2a-4c4f-a31f-29e71c6f8b35}')
    @winrt_commethod(3)
    def Invoke(self, precedingWords: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Data.Text.WordSegment], words: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Data.Text.WordSegment]) -> Void: ...
class WordsSegmenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Text.IWordsSegmenter
    _classid_ = 'Windows.Data.Text.WordsSegmenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Data.Text.WordsSegmenter.CreateWithLanguage(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateWithLanguage(cls: win32more.Windows.Data.Text.IWordsSegmenterFactory, language: WinRT_String) -> win32more.Windows.Data.Text.WordsSegmenter: ...
    @winrt_mixinmethod
    def get_ResolvedLanguage(self: win32more.Windows.Data.Text.IWordsSegmenter) -> WinRT_String: ...
    @winrt_mixinmethod
    def GetTokenAt(self: win32more.Windows.Data.Text.IWordsSegmenter, text: WinRT_String, startIndex: UInt32) -> win32more.Windows.Data.Text.WordSegment: ...
    @winrt_mixinmethod
    def GetTokens(self: win32more.Windows.Data.Text.IWordsSegmenter, text: WinRT_String) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Text.WordSegment]: ...
    @winrt_mixinmethod
    def Tokenize(self: win32more.Windows.Data.Text.IWordsSegmenter, text: WinRT_String, startIndex: UInt32, handler: win32more.Windows.Data.Text.WordSegmentsTokenizingHandler) -> Void: ...
    ResolvedLanguage = property(get_ResolvedLanguage, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security.Cryptography
import win32more.Windows.Win32.Security.Cryptography.Catalog
import win32more.Windows.Win32.Security.Cryptography.Sip
szOID_CATALOG_LIST: String = '1.3.6.1.4.1.311.12.1.1'
szOID_CATALOG_LIST_MEMBER: String = '1.3.6.1.4.1.311.12.1.2'
szOID_CATALOG_LIST_MEMBER2: String = '1.3.6.1.4.1.311.12.1.3'
CRYPTCAT_FILEEXT: String = 'CAT'
CRYPTCAT_MAX_MEMBERTAG: UInt32 = 64
CRYPTCAT_MEMBER_SORTED: UInt32 = 1073741824
CRYPTCAT_E_AREA_HEADER: UInt32 = 0
CRYPTCAT_E_AREA_MEMBER: UInt32 = 65536
CRYPTCAT_E_AREA_ATTRIBUTE: UInt32 = 131072
CRYPTCAT_E_CDF_UNSUPPORTED: UInt32 = 1
CRYPTCAT_E_CDF_DUPLICATE: UInt32 = 2
CRYPTCAT_E_CDF_TAGNOTFOUND: UInt32 = 4
CRYPTCAT_E_CDF_MEMBER_FILE_PATH: UInt32 = 65537
CRYPTCAT_E_CDF_MEMBER_INDIRECTDATA: UInt32 = 65538
CRYPTCAT_E_CDF_MEMBER_FILENOTFOUND: UInt32 = 65540
CRYPTCAT_E_CDF_BAD_GUID_CONV: UInt32 = 131073
CRYPTCAT_E_CDF_ATTR_TOOFEWVALUES: UInt32 = 131074
CRYPTCAT_E_CDF_ATTR_TYPECOMBO: UInt32 = 131076
CRYPTCAT_ADDCATALOG_NONE: UInt32 = 0
CRYPTCAT_ADDCATALOG_HARDLINK: UInt32 = 1
@winfunctype('WINTRUST.dll')
def CryptCATOpen(pwszFileName: win32more.Windows.Win32.Foundation.PWSTR, fdwOpenFlags: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCAT_OPEN_FLAGS, hProv: UIntPtr, dwPublicVersion: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCAT_VERSION, dwEncodingType: UInt32) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('WINTRUST.dll')
def CryptCATClose(hCatalog: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptCATStoreFromHandle(hCatalog: win32more.Windows.Win32.Foundation.HANDLE) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATSTORE): ...
@winfunctype('WINTRUST.dll')
def CryptCATHandleFromStore(pCatStore: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATSTORE)) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('WINTRUST.dll')
def CryptCATPersistStore(hCatalog: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptCATGetCatAttrInfo(hCatalog: win32more.Windows.Win32.Foundation.HANDLE, pwszReferenceTag: win32more.Windows.Win32.Foundation.PWSTR) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE): ...
@winfunctype('WINTRUST.dll')
def CryptCATPutCatAttrInfo(hCatalog: win32more.Windows.Win32.Foundation.HANDLE, pwszReferenceTag: win32more.Windows.Win32.Foundation.PWSTR, dwAttrTypeAndAction: UInt32, cbData: UInt32, pbData: POINTER(Byte)) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE): ...
@winfunctype('WINTRUST.dll')
def CryptCATEnumerateCatAttr(hCatalog: win32more.Windows.Win32.Foundation.HANDLE, pPrevAttr: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE)) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE): ...
@winfunctype('WINTRUST.dll')
def CryptCATGetMemberInfo(hCatalog: win32more.Windows.Win32.Foundation.HANDLE, pwszReferenceTag: win32more.Windows.Win32.Foundation.PWSTR) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATMEMBER): ...
@winfunctype('WINTRUST.dll')
def CryptCATAllocSortedMemberInfo(hCatalog: win32more.Windows.Win32.Foundation.HANDLE, pwszReferenceTag: win32more.Windows.Win32.Foundation.PWSTR) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATMEMBER): ...
@winfunctype('WINTRUST.dll')
def CryptCATFreeSortedMemberInfo(hCatalog: win32more.Windows.Win32.Foundation.HANDLE, pCatMember: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATMEMBER)) -> Void: ...
@winfunctype('WINTRUST.dll')
def CryptCATGetAttrInfo(hCatalog: win32more.Windows.Win32.Foundation.HANDLE, pCatMember: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATMEMBER), pwszReferenceTag: win32more.Windows.Win32.Foundation.PWSTR) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE): ...
@winfunctype('WINTRUST.dll')
def CryptCATPutMemberInfo(hCatalog: win32more.Windows.Win32.Foundation.HANDLE, pwszFileName: win32more.Windows.Win32.Foundation.PWSTR, pwszReferenceTag: win32more.Windows.Win32.Foundation.PWSTR, pgSubjectType: POINTER(Guid), dwCertVersion: UInt32, cbSIPIndirectData: UInt32, pbSIPIndirectData: POINTER(Byte)) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATMEMBER): ...
@winfunctype('WINTRUST.dll')
def CryptCATPutAttrInfo(hCatalog: win32more.Windows.Win32.Foundation.HANDLE, pCatMember: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATMEMBER), pwszReferenceTag: win32more.Windows.Win32.Foundation.PWSTR, dwAttrTypeAndAction: UInt32, cbData: UInt32, pbData: POINTER(Byte)) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE): ...
@winfunctype('WINTRUST.dll')
def CryptCATEnumerateMember(hCatalog: win32more.Windows.Win32.Foundation.HANDLE, pPrevMember: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATMEMBER)) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATMEMBER): ...
@winfunctype('WINTRUST.dll')
def CryptCATEnumerateAttr(hCatalog: win32more.Windows.Win32.Foundation.HANDLE, pCatMember: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATMEMBER), pPrevAttr: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE)) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE): ...
@winfunctype('WINTRUST.dll')
def CryptCATCDFOpen(pwszFilePath: win32more.Windows.Win32.Foundation.PWSTR, pfnParseError: win32more.Windows.Win32.Security.Cryptography.Catalog.PFN_CDF_PARSE_ERROR_CALLBACK) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATCDF): ...
@winfunctype('WINTRUST.dll')
def CryptCATCDFClose(pCDF: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATCDF)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptCATCDFEnumCatAttributes(pCDF: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATCDF), pPrevAttr: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE), pfnParseError: win32more.Windows.Win32.Security.Cryptography.Catalog.PFN_CDF_PARSE_ERROR_CALLBACK) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE): ...
@winfunctype('WINTRUST.dll')
def CryptCATCDFEnumMembers(pCDF: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATCDF), pPrevMember: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATMEMBER), pfnParseError: win32more.Windows.Win32.Security.Cryptography.Catalog.PFN_CDF_PARSE_ERROR_CALLBACK) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATMEMBER): ...
@winfunctype('WINTRUST.dll')
def CryptCATCDFEnumAttributes(pCDF: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATCDF), pMember: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATMEMBER), pPrevAttr: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE), pfnParseError: win32more.Windows.Win32.Security.Cryptography.Catalog.PFN_CDF_PARSE_ERROR_CALLBACK) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE): ...
@winfunctype('WINTRUST.dll')
def IsCatalogFile(hFile: win32more.Windows.Win32.Foundation.HANDLE, pwszFileName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptCATAdminAcquireContext(phCatAdmin: POINTER(IntPtr), pgSubsystem: POINTER(Guid), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptCATAdminAcquireContext2(phCatAdmin: POINTER(IntPtr), pgSubsystem: POINTER(Guid), pwszHashAlgorithm: win32more.Windows.Win32.Foundation.PWSTR, pStrongHashPolicy: POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_STRONG_SIGN_PARA), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptCATAdminReleaseContext(hCatAdmin: IntPtr, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptCATAdminReleaseCatalogContext(hCatAdmin: IntPtr, hCatInfo: IntPtr, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptCATAdminEnumCatalogFromHash(hCatAdmin: IntPtr, pbHash: POINTER(Byte), cbHash: UInt32, dwFlags: UInt32, phPrevCatInfo: POINTER(IntPtr)) -> IntPtr: ...
@winfunctype('WINTRUST.dll')
def CryptCATAdminCalcHashFromFileHandle(hFile: win32more.Windows.Win32.Foundation.HANDLE, pcbHash: POINTER(UInt32), pbHash: POINTER(Byte), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptCATAdminCalcHashFromFileHandle2(hCatAdmin: IntPtr, hFile: win32more.Windows.Win32.Foundation.HANDLE, pcbHash: POINTER(UInt32), pbHash: POINTER(Byte), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptCATAdminAddCatalog(hCatAdmin: IntPtr, pwszCatalogFile: win32more.Windows.Win32.Foundation.PWSTR, pwszSelectBaseName: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32) -> IntPtr: ...
@winfunctype('WINTRUST.dll')
def CryptCATAdminRemoveCatalog(hCatAdmin: IntPtr, pwszCatalogFile: win32more.Windows.Win32.Foundation.PWSTR, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptCATCatalogInfoFromContext(hCatInfo: IntPtr, psCatInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CATALOG_INFO), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptCATAdminResolveCatalogPath(hCatAdmin: IntPtr, pwszCatalogFile: win32more.Windows.Win32.Foundation.PWSTR, psCatInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CATALOG_INFO), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptCATAdminPauseServiceForBackup(dwFlags: UInt32, fResume: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptCATCDFEnumMembersByCDFTagEx(pCDF: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATCDF), pwszPrevCDFTag: win32more.Windows.Win32.Foundation.PWSTR, pfnParseError: win32more.Windows.Win32.Security.Cryptography.Catalog.PFN_CDF_PARSE_ERROR_CALLBACK, ppMember: POINTER(POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATMEMBER)), fContinueOnError: win32more.Windows.Win32.Foundation.BOOL, pvReserved: VoidPtr) -> win32more.Windows.Win32.Foundation.PWSTR: ...
@winfunctype('WINTRUST.dll')
def CryptCATCDFEnumAttributesWithCDFTag(pCDF: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATCDF), pwszMemberTag: win32more.Windows.Win32.Foundation.PWSTR, pMember: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATMEMBER), pPrevAttr: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE), pfnParseError: win32more.Windows.Win32.Security.Cryptography.Catalog.PFN_CDF_PARSE_ERROR_CALLBACK) -> POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE): ...
class CATALOG_INFO(Structure):
    cbStruct: UInt32
    wszCatalogFile: Char * 260
class CRYPTCATATTRIBUTE(Structure):
    cbStruct: UInt32
    pwszReferenceTag: win32more.Windows.Win32.Foundation.PWSTR
    dwAttrTypeAndAction: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE_FLAGS
    cbValue: UInt32
    pbValue: POINTER(Byte)
    dwReserved: UInt32
CRYPTCATATTRIBUTE_FLAGS = UInt32
CRYPTCAT_ATTR_AUTHENTICATED: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE_FLAGS = 268435456
CRYPTCAT_ATTR_UNAUTHENTICATED: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE_FLAGS = 536870912
CRYPTCAT_ATTR_NAMEASCII: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE_FLAGS = 1
CRYPTCAT_ATTR_NAMEOBJID: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE_FLAGS = 2
CRYPTCAT_ATTR_DATAASCII: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE_FLAGS = 65536
CRYPTCAT_ATTR_DATABASE64: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE_FLAGS = 131072
CRYPTCAT_ATTR_DATAREPLACE: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE_FLAGS = 262144
CRYPTCAT_ATTR_NO_AUTO_COMPAT_ENTRY: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATATTRIBUTE_FLAGS = 16777216
class CRYPTCATCDF(Structure):
    cbStruct: UInt32
    hFile: win32more.Windows.Win32.Foundation.HANDLE
    dwCurFilePos: UInt32
    dwLastMemberOffset: UInt32
    fEOF: win32more.Windows.Win32.Foundation.BOOL
    pwszResultDir: win32more.Windows.Win32.Foundation.PWSTR
    hCATStore: win32more.Windows.Win32.Foundation.HANDLE
class CRYPTCATMEMBER(Structure):
    cbStruct: UInt32
    pwszReferenceTag: win32more.Windows.Win32.Foundation.PWSTR
    pwszFileName: win32more.Windows.Win32.Foundation.PWSTR
    gSubjectType: Guid
    fdwMemberFlags: UInt32
    pIndirectData: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_INDIRECT_DATA)
    dwCertVersion: UInt32
    dwReserved: UInt32
    hReserved: win32more.Windows.Win32.Foundation.HANDLE
    sEncodedIndirectData: win32more.Windows.Win32.Security.Cryptography.CRYPT_INTEGER_BLOB
    sEncodedMemberInfo: win32more.Windows.Win32.Security.Cryptography.CRYPT_INTEGER_BLOB
class CRYPTCATSTORE(Structure):
    cbStruct: UInt32
    dwPublicVersion: UInt32
    pwszP7File: win32more.Windows.Win32.Foundation.PWSTR
    hProv: UIntPtr
    dwEncodingType: UInt32
    fdwStoreFlags: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCAT_OPEN_FLAGS
    hReserved: win32more.Windows.Win32.Foundation.HANDLE
    hAttrs: win32more.Windows.Win32.Foundation.HANDLE
    hCryptMsg: VoidPtr
    hSorted: win32more.Windows.Win32.Foundation.HANDLE
CRYPTCAT_OPEN_FLAGS = UInt32
CRYPTCAT_OPEN_ALWAYS: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCAT_OPEN_FLAGS = 2
CRYPTCAT_OPEN_CREATENEW: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCAT_OPEN_FLAGS = 1
CRYPTCAT_OPEN_EXISTING: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCAT_OPEN_FLAGS = 4
CRYPTCAT_OPEN_EXCLUDE_PAGE_HASHES: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCAT_OPEN_FLAGS = 65536
CRYPTCAT_OPEN_INCLUDE_PAGE_HASHES: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCAT_OPEN_FLAGS = 131072
CRYPTCAT_OPEN_VERIFYSIGHASH: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCAT_OPEN_FLAGS = 268435456
CRYPTCAT_OPEN_NO_CONTENT_HCRYPTMSG: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCAT_OPEN_FLAGS = 536870912
CRYPTCAT_OPEN_SORTED: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCAT_OPEN_FLAGS = 1073741824
CRYPTCAT_OPEN_FLAGS_MASK: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCAT_OPEN_FLAGS = 4294901760
CRYPTCAT_VERSION = UInt32
CRYPTCAT_VERSION_1: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCAT_VERSION = 256
CRYPTCAT_VERSION_2: win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCAT_VERSION = 512
class MS_ADDINFO_CATALOGMEMBER(Structure):
    cbStruct: UInt32
    pStore: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATSTORE)
    pMember: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.CRYPTCATMEMBER)
@winfunctype_pointer
def PFN_CDF_PARSE_ERROR_CALLBACK(dwErrorArea: UInt32, dwLocalError: UInt32, pwszLine: win32more.Windows.Win32.Foundation.PWSTR) -> Void: ...


make_ready(__name__)
